@@ -1,4 +1,4 @@
-from .models import BaseModel
+from .models import BaseModel, ModelKind
 from .fields import Field
 from .utils.pydantic_django import transfer_from_orm, transfer_to_orm
 from pydantic.fields import Undefined
